Histogram

Struct Histogram 

pub struct Histogram<T: Eq + Hash> {
    pub lookup: IndexMap<T, usize>,
}
A convenience to analyze the distribution of generated values

Fields

lookup: IndexMap<T, usize>

Implementations

Source

impl<T: Eq + Hash> Histogram<T>

pub fn from(iter: impl IntoIterator<Item = T>) -> Self

pub fn iter(&self) -> impl Iterator<Item = (&T, usize)>

Returns an iterator over the histogram entries, sorted by occurrence count in ascending order.