Dependent2

Struct Dependent2 

pub struct Dependent2<X, DX: Distribution<X> + Clone, Y, DY: Distribution<Y> + Clone, FDY: Fn(X) -> DY + Clone> {
    pub dx: DX,
    pub fdy: FDY,
    pub pd: PhantomData<(X, Y)>,
}
A distribution where the choice of the second distribution depends on the value sampled from the first.

Fields

dx: DXfdy: FDYpd: PhantomData<(X, Y)>